/*
 *  /MathJax/localization/zh-hant/MathMenu.js
 *
 *  Copyright (c) 2009-2018 The MathJax Consortium
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

MathJax.Localization.addTranslation("zh-hant","MathMenu",{version:"2.7.4",isLoaded:true,strings:{Show:"\u986F\u793A\u6578\u5B78\u5F62\u5F0F",MathMLcode:"MathML\u4EE3\u78BC",OriginalMathML:"\u539F\u59CBMathML",TeXCommands:"TeX\u547D\u4EE4",AsciiMathInput:"AsciiMathML\u8F38\u5165",Original:"\u539F\u59CB\u683C\u5F0F",ErrorMessage:"\u932F\u8AA4\u8A0A\u606F",Annotation:"\u8A3B\u91CB",TeX:"TeX",StarMath:"StarMath",Maple:"Maple",ContentMathML:"MathML\u5167\u5BB9",OpenMath:"OpenMath",texHints:"\u5728MathML\u986F\u793ATeX\u63D0\u793A",Settings:"\u6578\u5B78\u8A2D\u5B9A",ZoomTrigger:"\u7E2E\u653E\u89F8\u767C",Hover:"\u6E38\u6A19\u8986\u84CB",Click:"\u9EDE\u9078",DoubleClick:"\u96D9\u64CA",NoZoom:"\u95DC\u9589\u7E2E\u653E",TriggerRequires:"\u89F8\u767C\u9700\u6C42\uFF1A",Option:"\u9078\u9805",Alt:"Alt\u9375",Command:"Command\u9375",Control:"Ctrl\u9375",Shift:"Shift\u9375",ZoomFactor:"\u7E2E\u653E\u500D\u7387",Renderer:"\u5448\u73FE\u6578\u5B78\u65B9\u5F0F",MPHandles:"\u7531MathPlayer\u8655\u7406\uFF1A",MenuEvents:"\u9078\u55AE\u4E8B\u4EF6",MouseEvents:"\u6E38\u6A19\u4E8B\u4EF6",MenuAndMouse:"\u6E38\u6A19\u8207\u9078\u55AE\u4E8B\u4EF6",FontPrefs:"\u5B57\u578B\u504F\u597D\u8A2D\u5B9A",ForHTMLCSS:"\u7528\u65BCHTML-CSS\uFF1A",Auto:"\u81EA\u52D5",TeXLocal:"Tex\uFF08\u672C\u5730\uFF09",TeXWeb:"Tex\uFF08\u7DB2\u9801\uFF09",TeXImage:"Tex\uFF08\u5716\u50CF\uFF09",STIXLocal:"STIX\uFF08\u672C\u5730\uFF09",STIXWeb:"STIX\uFF08\u7DB2\u9801\uFF09",AsanaMathWeb:"Asana Math\uFF08\u7DB2\u9801\uFF09",GyrePagellaWeb:"Gyre Pagella\uFF08\u7DB2\u9801\uFF09",GyreTermesWeb:"Gyre Termes\uFF08\u7DB2\u9801\uFF09",LatinModernWeb:"Latin Modern\uFF08\u7DB2\u9801\uFF09",NeoEulerWeb:"Neo Euler\uFF08\u7DB2\u9801\uFF09",ContextMenu:"\u4E0A\u4E0B\u6587\u9078\u55AE",Browser:"\u700F\u89BD\u5668",Scale:"\u7E2E\u653E\u6240\u6709\u6578\u5B78\u516C\u5F0F\u2027\u2027\u2027",Discoverable:"\u5728\u6E38\u6A19\u8986\u84CB\u6642\u5F37\u8ABF\u5167\u5BB9",Locale:"\u8A9E\u8A00",LoadLocale:"\u5F9EURL\u8F09\u5165...",About:"\u95DC\u65BCMathJax",Help:"MathJax\u8AAA\u660E",localTeXfonts:"\u4F7F\u7528\u672C\u5730TeX\u5B57\u578B",webTeXfonts:"\u4F7F\u7528\u7DB2\u9801TeX\u5B57\u578B",imagefonts:"\u4F7F\u7528\u5716\u50CF\u5B57\u578B",localSTIXfonts:"\u4F7F\u7528\u672C\u5730STIX\u5B57\u578B",webSVGfonts:"\u4F7F\u7528\u7DB2\u9801SVG\u5B57\u578B",genericfonts:"\u4F7F\u7528\u901A\u7528\u842C\u570B\u78BC\u5B57\u578B",wofforotffonts:"WOFF\u6216OTF\u5B57\u578B",eotffonts:"EOT\u5B57\u578B",svgfonts:"SVG\u5B57\u578B",WebkitNativeMMLWarning:"\u60A8\u7684\u700F\u89BD\u5668\u4E0D\u652F\u63F4MathML natively\uFF0C\u56E0\u6B64\u5207\u63DB\u81F3MathML\u8F38\u51FA\u53EF\u80FD\u6703\u5C0E\u81F4\u9801\u9762\u4E0A\u7684\u6578\u5B78\u516C\u5F0F\u7121\u6CD5\u8B80\u53D6\u3002",MSIENativeMMLWarning:"IE\u700F\u89BD\u5668\u9700\u8981MathPlayer\u5916\u639B\u624D\u80FD\u8655\u7406MathML\u8F38\u51FA\u5167\u5BB9\u3002",OperaNativeMMLWarning:"Opera\u700F\u89BD\u5668\u5728\u5C0D\u65BC\u652F\u63F4MathML\u65B9\u9762\u6709\u9650\uFF0C\u6240\u4EE5\u8F49\u63DB\u81F3MathML\u8F38\u51FA\u4E5F\u8A31\u6703\u9020\u6210\u4E00\u4E9B\u8868\u9054\u5F0F\u4E0D\u80FD\u6B63\u78BA\u5448\u73FE\u3002",SafariNativeMMLWarning:"\u60A8\u7684\u700F\u89BD\u5668\u9644\u52A0\u5143\u4EF6native MathML\u4E0D\u652F\u63F4\u6240\u6709MathJax\u529F\u80FD\uFF0C\u6240\u4EE5\u8868\u9054\u5F0F\u53EF\u80FD\u7121\u6CD5\u6B63\u5E38\u5448\u73FE\u3002",FirefoxNativeMMLWarning:"\u60A8\u7684\u700F\u89BD\u5668\u9644\u52A0\u5143\u4EF6native MathML\u4E0D\u652F\u63F4\u6240\u6709MathJax\u529F\u80FD\uFF0C\u6240\u4EE5\u8868\u9054\u5F0F\u53EF\u80FD\u7121\u6CD5\u6B63\u5E38\u5448\u73FE\u3002",MSIESVGWarning:"SVG\u5728IE9\u4E4B\u524D\u7248\u672C\u7684IE\u700F\u89BD\u5668\u3001\u6216\u8B93IE9\u6A21\u64ECIE8\u4EE5\u4E0B\u67B6\u69CB\u904B\u4F5C\u6642\uFF0C\u5728\u8F49\u63DB\u81F3SVG\u8F38\u51FA\u6703\u5C0E\u81F4\u6578\u5B78\u516C\u5F0F\u7121\u6CD5\u6B63\u5E38\u986F\u793A\u3002",LoadURL:"\u5F9E\u6B64URL\u8F09\u5165\u8F49\u63DB\u8CC7\u6599\uFF1A",BadURL:"URL\u61C9\u8A72\u662F\u500B\u5B9A\u7FA9MathJax\u8F49\u63DB\u8CC7\u6599\u7684JavaScript\u6A94\u6848\u3002JavaScript\u6A94\u6848\u540D\u7A31\u7D50\u5C3E\u61C9\u70BA\u300C.js\u300D\u3002",BadData:"\u5F9E%1\u8F09\u5165\u8F49\u63DB\u8CC7\u6599\u51FA\u932F",SwitchAnyway:"\u4E00\u5B9A\u8981\u5207\u63DB\u5448\u73FE\u65B9\u5F0F\uFF1F\n\n\uFF08\u9EDE\u64CAOK\u9032\u884C\u5207\u63DB\uFF0C\u9EDE\u64CA\u53D6\u6D88\u7E7C\u7E8C\u4EE5\u76EE\u524D\u65B9\u5F0F\u5448\u73FE\uFF09",ScaleMath:"\u7E2E\u653E\u6240\u6709\u6578\u5B78\u516C\u5F0F\uFF08\u8207\u570D\u7E5E\u7684\u6587\u5B57\u505A\u5C0D\u6BD4\uFF09\u4F9D",NonZeroScale:"\u6BD4\u4F8B\u4E0D\u61C9\u70BA\u96F6",PercentScale:"\u6BD4\u4F8B\u61C9\u70BA\u767E\u5206\u6BD4\u683C\u5F0F\uFF08\u4F8B\u5982120%%\uFF09",IE8warning:"\u9019\u5C07\u6703\u95DC\u9589MathJax\u9078\u55AE\u4EE5\u53CA\u7E2E\u653E\u529F\u80FD\uFF0C\u4F46\u60A8\u53EF\u4EE5\u5728\u67D0\u4E00\u8868\u9054\u5F0F\u4E0A\u540C\u6642\u6309\u4E0BAlt\u9375\u548C\u6ED1\u9F20\u5DE6\u9375\u4F86\u9032\u5165MathJax\u9078\u55AE\u3002\n\n\u78BA\u5B9A\u8981\u66F4\u6539MathPlayer\u8A2D\u5B9A\uFF1F",IE9warning:"MathJax\u5FEB\u6377\u9078\u55AE\u5C07\u6703\u88AB\u505C\u7528\uFF0C\u4F46\u60A8\u53EF\u4EE5\u5728\u67D0\u500B\u8868\u9054\u5F0F\u4E0A\u540C\u6642\u6309\u4E0BAlt\u9375\u548C\u6ED1\u9F20\u5DE6\u9375\u4F86\u547C\u53EB\u9078\u55AE\u3002",NoOriginalForm:"\u6C92\u6709\u53EF\u7528\u7684\u539F\u59CB\u683C\u5F0F",Close:"\u95DC\u9589",EqSource:"MathJax\u65B9\u7A0B\u5F0F\u4F86\u6E90",CloseAboutDialog:"\u95DC\u9589\u95DC\u65BCMathJax\u5C0D\u8A71\u6846",FastPreview:"\u5FEB\u901F\u9810\u89BD",AssistiveMML:"\u8F14\u52A9MathML",InTabOrder:"\u5305\u542B\u5728\u6A19\u7C64\u9806\u5E8F\u88E1"}});MathJax.Ajax.loadComplete("[MathJax]/localization/zh-hant/MathMenu.js");
