/*
 *  /MathJax/localization/pl/FontWarnings.js
 *
 *  Copyright (c) 2009-2018 The MathJax Consortium
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

MathJax.Localization.addTranslation("pl","FontWarnings",{version:"2.7.4",isLoaded:true,strings:{webFont:"MathJax u\u017Cywa czcionek Web, aby wy\u015Bwietli\u0107 wzory matematyczne na tej stronie. Pobranie czcionek z sieci zajmuje chwil\u0119. Strona ta mog\u0142aby za\u0142adowa\u0107 si\u0119 szybciej, je\u015Bli zainstalowa\u0142by\u015B czcionki lokalnie w swoim systemie.",imageFonts:"MathJax u\u017Cywa czcionek obrazkowych zamiast lokalnych lub pobranych z sieci. To powoduje wolniejsze wy\u015Bwietlanie strony oraz uniemo\u017Cliwia wydruk w pe\u0142nej rozdzielczo\u015Bci Twojej drukarki.",noFonts:"MathJax nie mo\u017Ce zlokalizowa\u0107 czcionek potrzebnych do wy\u015Bwietlenia wzor\u00F3w, a czcionki obrazkowe nie s\u0105 dost\u0119pne. U\u017Cywane s\u0105 wi\u0119c znaki Unicode z nadziej\u0105, \u017Ce Twoja przegl\u0105darka wy\u015Bwietli je poprawnie. Niekt\u00F3re znaki mog\u0105 jednak nie wygl\u0105da\u0107 prawid\u0142owo lub mog\u0105 nie by\u0107 w og\u00F3le wy\u015Bwietlane.",webFonts:"Wi\u0119kszo\u015B\u0107 nowych przegl\u0105darek umo\u017Cliwia pobieranie czcionek z sieci Web. Aktualizacja Twojej przegl\u0105darki (lub wyb\u00F3r innej) mo\u017Ce polepszy\u0107 jako\u015B\u0107 wy\u015Bwietlanych wzor\u00F3w matematycznych na tej stronie.",fonts:"MathJax mo\u017Ce u\u017Cy\u0107 albo [czcionek STIX](%1), albo [czcionek MathJax Tex](%2). Pobierz i zainstaluj te czcionki, aby ulepszy\u0107 dzia\u0142anie MathJax.",STIXPage:"Ta strona wymaga [czcionek STIX](%1). Pobierz i zainstaluj te czcionki, aby ulepszy\u0107 dzia\u0142anie MathJax.",TeXPage:"Ta strona wymaga [czcionek MathJax Tex](%1). Pobierz i zainstaluj te czcionki, aby ulepszy\u0107 dzia\u0142anie MathJax."}});MathJax.Ajax.loadComplete("[MathJax]/localization/pl/FontWarnings.js");
